==> jc-1.4.0.tar.gz: gnu/xml/xpath/NamespaceTest.h <==
// public final class gnu.xml.xpath.NamespaceTest

// class file dependencies
// @dep_class 4422a37e549dceda gnu_xml_xpath_NamespaceTest
// @dep_class d99963ba20fa6197 gnu_xml_xpath_Test
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Test

#include "gnu/xml/xpath/Test.h"

#ifndef _JC_gnu_xml_xpath_NamespaceTest_H_
#define _JC_gnu_xml_xpath_NamespaceTest_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Test$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_NamespaceTest$sub_refs	_jc_gnu_xml_xpath_NamespaceTest$sub_refs;
typedef struct _jc_gnu_xml_xpath_NamespaceTest$sub_nonrefs	_jc_gnu_xml_xpath_NamespaceTest$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_NamespaceTest$refs	_jc_gnu_xml_xpath_NamespaceTest$refs;
typedef struct _jc_gnu_xml_xpath_NamespaceTest$nonrefs	_jc_gnu_xml_xpath_NamespaceTest$nonrefs;
typedef struct _jc_gnu_xml_xpath_NamespaceTest$object	_jc_gnu_xml_xpath_NamespaceTest$object;

typedef const struct _jc_gnu_xml_xpath_NamespaceTest$vmethods	_jc_gnu_xml_xpath_NamespaceTest$vmethods;
typedef const struct _jc_gnu_xml_xpath_NamespaceTest$vtable	_jc_gnu_xml_xpath_NamespaceTest$vtable;
typedef const struct _jc_gnu_xml_xpath_NamespaceTest$vtype	_jc_gnu_xml_xpath_NamespaceTest$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_NamespaceTest$method$_init$2328effa9e120d60(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *, struct _jc_javax_xml_namespace_QName$object *, jboolean, jboolean);

// Virtual methods
extern struct _jc_gnu_xml_xpath_Test$object *_jc_gnu_xml_xpath_NamespaceTest$method$clone$73a8d2a4d673dd95(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_gnu_xml_xpath_NamespaceTest$method$matches$528a77e426fd27f8(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *, struct _jc_object *, jint, jint);
extern jboolean _jc_gnu_xml_xpath_NamespaceTest$method$matchesAny$da292486ca30cd28(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *);
extern jboolean _jc_gnu_xml_xpath_NamespaceTest$method$matchesAnyLocalName$bcad85095823a064(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_NamespaceTest$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_NamespaceTest$method_info$clone$73a8d2a4d673dd95;
extern _jc_method _jc_gnu_xml_xpath_NamespaceTest$method_info$matches$528a77e426fd27f8;
extern _jc_method _jc_gnu_xml_xpath_NamespaceTest$method_info$matchesAny$da292486ca30cd28;
extern _jc_method _jc_gnu_xml_xpath_NamespaceTest$method_info$matchesAnyLocalName$bcad85095823a064;
extern _jc_method _jc_gnu_xml_xpath_NamespaceTest$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_NamespaceTest$vmethods {
	struct _jc_gnu_xml_xpath_Test$object	*(*clone$73a8d2a4d673dd95)(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*matches$528a77e426fd27f8)(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *, struct _jc_object *, jint, jint);
	jboolean	(*matchesAny$da292486ca30cd28)(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *);
	jboolean	(*matchesAnyLocalName$bcad85095823a064)(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *);
};

// Vtable
struct _jc_gnu_xml_xpath_NamespaceTest$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Test$vmethods	gnu_xml_xpath_Test;
	_jc_gnu_xml_xpath_NamespaceTest$vmethods	gnu_xml_xpath_NamespaceTest;
};

// Vtype
struct _jc_gnu_xml_xpath_NamespaceTest$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_NamespaceTest$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_NamespaceTest$sub_refs {
	struct _jc_javax_xml_namespace_QName$object	*qName;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_NamespaceTest$refs {
    _jc_gnu_xml_xpath_NamespaceTest$sub_refs	gnu_xml_xpath_NamespaceTest;
    _jc_gnu_xml_xpath_Test$sub_refs	gnu_xml_xpath_Test;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_NamespaceTest$sub_nonrefs {
	jboolean	anyLocalName;
	jboolean	any;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_NamespaceTest$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Test$sub_nonrefs	gnu_xml_xpath_Test;
    _jc_gnu_xml_xpath_NamespaceTest$sub_nonrefs	gnu_xml_xpath_NamespaceTest;
};

// Object instance structure
struct _jc_gnu_xml_xpath_NamespaceTest$object {
	_jc_gnu_xml_xpath_NamespaceTest$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_NamespaceTest$vtype	*vtype;
	_jc_gnu_xml_xpath_NamespaceTest$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_NamespaceTest$vtype _jc_gnu_xml_xpath_NamespaceTest$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_NamespaceTest, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_NamespaceTest$class_object;

#endif	/* _JC_gnu_xml_xpath_NamespaceTest_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/NamespaceTest.h <==
// public final class gnu.xml.xpath.NamespaceTest

// class file dependencies
// @dep_class 4422a37e549dceda gnu_xml_xpath_NamespaceTest
// @dep_class d99963ba20fa6197 gnu_xml_xpath_Test
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Test

#include "gnu/xml/xpath/Test.h"

#ifndef _JC_gnu_xml_xpath_NamespaceTest_H_
#define _JC_gnu_xml_xpath_NamespaceTest_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Test$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_NamespaceTest$sub_refs	_jc_gnu_xml_xpath_NamespaceTest$sub_refs;
typedef struct _jc_gnu_xml_xpath_NamespaceTest$sub_nonrefs	_jc_gnu_xml_xpath_NamespaceTest$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_NamespaceTest$refs	_jc_gnu_xml_xpath_NamespaceTest$refs;
typedef struct _jc_gnu_xml_xpath_NamespaceTest$nonrefs	_jc_gnu_xml_xpath_NamespaceTest$nonrefs;
typedef struct _jc_gnu_xml_xpath_NamespaceTest$object	_jc_gnu_xml_xpath_NamespaceTest$object;

typedef const struct _jc_gnu_xml_xpath_NamespaceTest$vmethods	_jc_gnu_xml_xpath_NamespaceTest$vmethods;
typedef const struct _jc_gnu_xml_xpath_NamespaceTest$vtable	_jc_gnu_xml_xpath_NamespaceTest$vtable;
typedef const struct _jc_gnu_xml_xpath_NamespaceTest$vtype	_jc_gnu_xml_xpath_NamespaceTest$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_NamespaceTest$method$_init$2328effa9e120d60(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *, struct _jc_javax_xml_namespace_QName$object *, jboolean, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_xpath_Test$object *_jc_gnu_xml_xpath_NamespaceTest$method$clone$73a8d2a4d673dd95(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_xpath_NamespaceTest$method$matches$528a77e426fd27f8(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_xpath_NamespaceTest$method$matchesAny$da292486ca30cd28(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_xpath_NamespaceTest$method$matchesAnyLocalName$bcad85095823a064(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_NamespaceTest$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_NamespaceTest$method_info$clone$73a8d2a4d673dd95;
extern _jc_method _jc_gnu_xml_xpath_NamespaceTest$method_info$matches$528a77e426fd27f8;
extern _jc_method _jc_gnu_xml_xpath_NamespaceTest$method_info$matchesAny$da292486ca30cd28;
extern _jc_method _jc_gnu_xml_xpath_NamespaceTest$method_info$matchesAnyLocalName$bcad85095823a064;
extern _jc_method _jc_gnu_xml_xpath_NamespaceTest$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_NamespaceTest$vmethods {
	struct _jc_gnu_xml_xpath_Test$object	*(*clone$73a8d2a4d673dd95)(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*matches$528a77e426fd27f8)(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	jboolean	(*matchesAny$da292486ca30cd28)(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *) _JC_JCNI_ATTR;
	jboolean	(*matchesAnyLocalName$bcad85095823a064)(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_NamespaceTest$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_xpath_NamespaceTest$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Test$vmethods	gnu_xml_xpath_Test;
	_jc_gnu_xml_xpath_NamespaceTest$vmethods	gnu_xml_xpath_NamespaceTest;
};

// Vtype
struct _jc_gnu_xml_xpath_NamespaceTest$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_NamespaceTest$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_NamespaceTest$sub_refs {
	struct _jc_javax_xml_namespace_QName$object	*qName;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_NamespaceTest$refs {
    _jc_gnu_xml_xpath_NamespaceTest$sub_refs	gnu_xml_xpath_NamespaceTest;
    _jc_gnu_xml_xpath_Test$sub_refs	gnu_xml_xpath_Test;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_NamespaceTest$sub_nonrefs {
	jboolean	anyLocalName;
	jboolean	any;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_NamespaceTest$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Test$sub_nonrefs	gnu_xml_xpath_Test;
    _jc_gnu_xml_xpath_NamespaceTest$sub_nonrefs	gnu_xml_xpath_NamespaceTest;
};

// Object instance structure
struct _jc_gnu_xml_xpath_NamespaceTest$object {
	_jc_gnu_xml_xpath_NamespaceTest$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_NamespaceTest$vtype	*vtype;
	_jc_gnu_xml_xpath_NamespaceTest$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_NamespaceTest$vtype _jc_gnu_xml_xpath_NamespaceTest$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_NamespaceTest, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_NamespaceTest$class_object;

#endif	/* _JC_gnu_xml_xpath_NamespaceTest_H_ */
